"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
require("es6-promise/auto");
var chalk = require("chalk");
var memFs = require("mem-fs");
var fsEditor = require("mem-fs-editor");
var node_emoji_1 = require("node-emoji");
var ProgressBar = require("progress");
var immutable_1 = require("immutable");
var inquirer_1 = require("inquirer");
// This monkeypatch is necessary for for–await-of to work in Typescript v2.4+
Symbol.asyncIterator =
    Symbol.asyncIterator || Symbol.for("Symbol.asyncIterator");
var Migrator = /** @class */ (function () {
    function Migrator() {
        this.progressBar = new ProgressBar(" [:bar] " + chalk.bold(":current/:total") + " steps complete", {
            total: Migrator.steps.size - 1,
            complete: chalk.bold.green("="),
            incomplete: chalk.green("-"),
            width: 20
        });
    }
    Migrator.prototype.perform = function (options) {
        return tslib_1.__asyncGenerator(this, arguments, function perform_1() {
            var _a, _b, stepName, step, newOptions, e_1_1, e_1, _c;
            return tslib_1.__generator(this, function (_d) {
                switch (_d.label) {
                    case 0:
                        _d.trys.push([0, 6, 7, 8]);
                        _a = tslib_1.__values(Migrator.steps), _b = _a.next();
                        _d.label = 1;
                    case 1:
                        if (!!_b.done) return [3 /*break*/, 5];
                        stepName = _b.value;
                        options = options.set("step", stepName);
                        step = require("./steps/" + stepName).default;
                        return [4 /*yield*/, tslib_1.__await(step(options))];
                    case 2:
                        newOptions = _d.sent();
                        options = options.merge(newOptions);
                        return [4 /*yield*/, options];
                    case 3:
                        _d.sent();
                        _d.label = 4;
                    case 4:
                        _b = _a.next();
                        return [3 /*break*/, 1];
                    case 5: return [3 /*break*/, 8];
                    case 6:
                        e_1_1 = _d.sent();
                        e_1 = { error: e_1_1 };
                        return [3 /*break*/, 8];
                    case 7:
                        try {
                            if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                        }
                        finally { if (e_1) throw e_1.error; }
                        return [7 /*endfinally*/];
                    case 8: return [2 /*return*/];
                }
            });
        });
    };
    Migrator.migrate = function (cliOptions) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var store, editor, migratr, options, auto, _a, _b, newOptions, e_2_1, err_1, e_2, _c;
            return tslib_1.__generator(this, function (_d) {
                switch (_d.label) {
                    case 0:
                        store = memFs.create();
                        editor = fsEditor.create(store);
                        migratr = new Migrator();
                        options = immutable_1.Map({
                            editor: editor
                        }).merge(cliOptions);
                        if (!cliOptions.auto) return [3 /*break*/, 2];
                        return [4 /*yield*/, inquirer_1.prompt([
                                {
                                    type: "confirm",
                                    name: "auto",
                                    message: "You've used the " + chalk.bold("auto") + " flag.  Auto migration is experimental and may be unstable, do you wish to proceed anyway?",
                                    default: true
                                }
                            ])];
                    case 1:
                        auto = (_d.sent()).auto;
                        if (!auto) {
                            console.log(chalk.bold.red("Migration cancelled " + node_emoji_1.emojify(":crying_cat_face:")));
                            return [2 /*return*/];
                        }
                        _d.label = 2;
                    case 2:
                        _d.trys.push([2, 16, , 17]);
                        _d.label = 3;
                    case 3:
                        _d.trys.push([3, 9, 10, 15]);
                        _a = tslib_1.__asyncValues(migratr.perform(options));
                        _d.label = 4;
                    case 4: return [4 /*yield*/, _a.next()];
                    case 5:
                        if (!(_b = _d.sent(), !_b.done)) return [3 /*break*/, 8];
                        return [4 /*yield*/, _b.value];
                    case 6:
                        newOptions = _d.sent();
                        if (!migratr.progressBar.complete)
                            migratr.progressBar.tick();
                        _d.label = 7;
                    case 7: return [3 /*break*/, 4];
                    case 8: return [3 /*break*/, 15];
                    case 9:
                        e_2_1 = _d.sent();
                        e_2 = { error: e_2_1 };
                        return [3 /*break*/, 15];
                    case 10:
                        _d.trys.push([10, , 13, 14]);
                        if (!(_b && !_b.done && (_c = _a.return))) return [3 /*break*/, 12];
                        return [4 /*yield*/, _c.call(_a)];
                    case 11:
                        _d.sent();
                        _d.label = 12;
                    case 12: return [3 /*break*/, 14];
                    case 13:
                        if (e_2) throw e_2.error;
                        return [7 /*endfinally*/];
                    case 14: return [7 /*endfinally*/];
                    case 15:
                        console.log(chalk.bold.green(node_emoji_1.emojify("Finished all steps! :rocket:")));
                        return [3 /*break*/, 17];
                    case 16:
                        err_1 = _d.sent();
                        migratr.progressBar.interrupt(chalk.bold.red(err_1.message));
                        throw err_1;
                    case 17: return [2 /*return*/];
                }
            });
        });
    };
    Migrator.steps = immutable_1.List([
        "setup_paths",
        "correct_version",
        "marketing_only",
        "requirements_only",
        "setup_app_scaffold",
        "migrate_common_js",
        "migrate_app_js",
        "migrate_app_css",
        "migrate_templates",
        "migrate_translations",
        "migrate_images",
        "migrate_manifest",
        "commit_changes",
        "run_scripts"
    ]);
    return Migrator;
}());
exports.default = Migrator;
