"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var babylon_1 = require("babylon");
var types = require("babel-types");
var babel_generator_1 = require("babel-generator");
var sync_to_async_1 = require("../plugins/sync_to_async");
var path_1 = require("path");
var prettier_1 = require("prettier");
var lodash_1 = require("lodash");
var utils_1 = require("../utils");
exports.default = function (options) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    var src, dest, editor, auto, tplSrc, appJsSrc, appJs, code, copyOptions, ast, returnStatementPath, iifePath, json, cache, cache_1, cache_1_1, _a, key, value, indexTpl, destJs, e_1, _b;
    return tslib_1.__generator(this, function (_c) {
        src = options.get("src");
        dest = options.get("dest");
        editor = options.get("editor");
        auto = options.get("auto");
        tplSrc = path_1.resolve(__dirname, "..", "..", "src", "templates");
        appJsSrc = path_1.join(src, "app.js");
        appJs = editor.read(appJsSrc);
        code = "\n    (function() {\n      return { /* no-op */ };\n    }());\n  ";
        copyOptions = {
            code: code,
            helpers: {}
        };
        ast = babylon_1.parse(appJs);
        returnStatementPath = utils_1.findLowestDepthPath(ast, "ReturnStatement");
        if (returnStatementPath) {
            iifePath = returnStatementPath.findParent(function (path) {
                return path.isExpressionStatement();
            });
            if (iifePath.isExpressionStatement()) {
                ast.program = types.program([iifePath.node]);
            }
            // Process any require statements to make them
            // relative to the lib folder.  No need to actually
            // resolve a file here
            iifePath.traverse({
                CallExpression: function (path) {
                    if (utils_1.isRequireStatement(path)) {
                        var pathToModule = path.get("arguments.0").node.value;
                        if (!/^\.\/lib\//.test(pathToModule)) {
                            path
                                .get("arguments.0")
                                .replaceWithSourceString("\"./lib/" + pathToModule + "\"");
                        }
                    }
                }
            });
            if (auto) {
                json = editor.readJSON(path_1.join(src, "manifest.json"));
                cache = new Map();
                sync_to_async_1.default(json, returnStatementPath, cache);
                if (cache.has("uiWidgets")) {
                    editor.copy(path_1.join(tplSrc, "zendesk_menus.js"), path_1.join(dest, "lib", "javascripts", "zendesk_menus.js"));
                    editor.write(path_1.join(dest, ".eslintignore"), "**/zendesk_menus.js");
                    copyOptions.helpers.uiWidgets = true;
                    options = options.set("uiWidgets", true);
                }
                try {
                    // If any of the methods have been changed to async (because they _now_ use the SDK)
                    // This should only be the case if the app uses a core API, like `this.currentUser()`, or
                    // if it uses a location-specific API, like `this.user()` or `this.ticket()`
                    for (cache_1 = tslib_1.__values(cache), cache_1_1 = cache_1.next(); !cache_1_1.done; cache_1_1 = cache_1.next()) {
                        _a = tslib_1.__read(cache_1_1.value, 2), key = _a[0], value = _a[1];
                        if ((copyOptions.helpers.async = lodash_1.get(value, "async", false)))
                            break;
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (cache_1_1 && !cache_1_1.done && (_b = cache_1.return)) _b.call(cache_1);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
            // Generate the final JavaScript for the app subclass definition
            copyOptions.code = babel_generator_1.default(ast).code;
        }
        indexTpl = path_1.join(tplSrc, "legacy_app.ejs");
        destJs = path_1.join(dest, "src", "javascripts", "legacy_app.js");
        editor.copyTpl(indexTpl, destJs, copyOptions);
        // FIXME: Unfortunately, `copyTpl` doesn't work as advertised,
        // it _should_ allow a process function that would make it possible
        // to format the contents of the file during the copy operation... :(
        editor.write(destJs, prettier_1.format(editor.read(destJs)));
        return [2 /*return*/];
    });
}); };
