"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var memFs = require("mem-fs");
var fsEditor = require("mem-fs-editor");
var shelljs_1 = require("shelljs");
var migrate_app_css_1 = require("../../steps/migrate_app_css");
var immutable_1 = require("immutable");
describe("migrate app css", function () {
    var editor;
    var options;
    var importZdMenuRegex = /@import "\.\/zendesk_menus";/;
    var cwd = process.cwd();
    var src = cwd + "/tmp/test/v1_app";
    var dest = cwd + "/tmp/test/v2_app";
    beforeEach(function () {
        shelljs_1.mkdir("-p", [
            src,
            dest + "/src/stylesheets"
        ]);
        editor = fsEditor.create(memFs.create());
        options = immutable_1.Map({ src: src, dest: dest, editor: editor });
        editor.write(src + "/app.css", ".sampleClass { color: red; }");
    });
    afterEach(function () {
        shelljs_1.rm("-rf", [src, dest]);
    });
    it("should copy v1 CSS to an SCSS file", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, migrate_app_css_1.default(options)];
                case 1:
                    _a.sent();
                    chai_1.expect(editor.exists(dest + "/src/stylesheets/app.scss")).to.be.true;
                    return [2 /*return*/];
            }
        });
    }); });
    it("should wrap the original CSS in a wildcard selector", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var css;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, migrate_app_css_1.default(options)];
                case 1:
                    _a.sent();
                    css = editor.read(dest + "/src/stylesheets/app.scss");
                    chai_1.expect(css).to.match(/^\* \{/);
                    chai_1.expect(css).to.match(/\.sampleClass \{/);
                    return [2 /*return*/];
            }
        });
    }); });
    it("should add a comment where there is no CSS to wrap", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var css;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    editor.write(src + "/app.css", "");
                    return [4 /*yield*/, migrate_app_css_1.default(options)];
                case 1:
                    _a.sent();
                    css = editor.read(dest + "/src/stylesheets/app.scss");
                    chai_1.expect(css).to.match(/\/\* Add CSS here... \*\//);
                    return [2 /*return*/];
            }
        });
    }); });
    describe("when uiWidgets flag is false or not set", function () {
        it("should not copy zendesk_menu.css template", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, migrate_app_css_1.default(options)];
                    case 1:
                        _a.sent();
                        chai_1.expect(editor.exists(dest + "/src/stylesheets/zendesk_menus.css")).to.be.false;
                        return [2 /*return*/];
                }
            });
        }); });
        it("should not import zendesk_menu in the new SCSS file", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var css;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, migrate_app_css_1.default(options)];
                    case 1:
                        _a.sent();
                        css = editor.read(dest + "/src/stylesheets/app.scss");
                        chai_1.expect(css).not.to.match(importZdMenuRegex);
                        return [2 /*return*/];
                }
            });
        }); });
    });
    describe("when uiWidgets flag is true", function () {
        beforeEach(function () {
            options = options.set("uiWidgets", true);
        });
        it("should copy zendesk_menu template", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, migrate_app_css_1.default(options)];
                    case 1:
                        _a.sent();
                        chai_1.expect(editor.exists(dest + "/src/stylesheets/zendesk_menus.css")).to.be.true;
                        return [2 /*return*/];
                }
            });
        }); });
        it("should import zendesk_menu in the new SCSS file", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var css;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, migrate_app_css_1.default(options)];
                    case 1:
                        _a.sent();
                        css = editor.read(dest + "/src/stylesheets/app.scss");
                        chai_1.expect(css).to.match(importZdMenuRegex);
                        return [2 /*return*/];
                }
            });
        }); });
    });
});
