"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var shelljs_1 = require("shelljs");
var memFs = require("mem-fs");
var fsEditor = require("mem-fs-editor");
var migrate_common_js_1 = require("../../steps/migrate_common_js");
var immutable_1 = require("immutable");
describe("migrate common js", function () {
    var editor;
    var options;
    var cwd = process.cwd();
    var src = cwd + "/tmp/test/v1_app";
    var dest = cwd + "/tmp/test/v2_app";
    var sampleCode = "\n    module.exports = {\n      test: function() { return true }\n    };\n  ";
    var sampleImport = "\n    module.exports = {\n      string: require(\"utils/test_utils.js\")\n    };\n  ";
    beforeEach(function () {
        shelljs_1.mkdir("-p", [src + "/lib/utils", dest + "/src/javascripts"]);
        editor = fsEditor.create(memFs.create());
        options = immutable_1.Map({ src: src, dest: dest, editor: editor });
        shelljs_1.exec("echo '" + sampleCode + "' > " + src + "/lib/utils/test_utils.js");
        shelljs_1.exec("echo '" + sampleImport + "' > " + src + "/lib/test.js");
    });
    afterEach(function () {
        shelljs_1.rm("-rf", [src, dest]);
    });
    describe("with no v1 `lib` folder", function () {
        beforeEach(function () {
            var pth = src + "/lib";
            if (shelljs_1.test("-e", pth)) {
                shelljs_1.rm("-rf", pth);
            }
        });
        it("does nothing", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, migrate_common_js_1.default(options)];
                    case 1:
                        options = _a.sent();
                        chai_1.expect(options).not.to.exist;
                        chai_1.expect(editor.exists(dest + "/src/javascripts/lib/test.js")).to.be.false;
                        return [2 /*return*/];
                }
            });
        }); });
    });
    describe("with a v1 `lib` folder", function () {
        it("copies the lib folder to the destination", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, migrate_common_js_1.default(options)];
                    case 1:
                        options = _a.sent();
                        chai_1.expect(options.get("hasCommonJs")).to.be.true;
                        chai_1.expect(editor.exists(dest + "/src/javascripts/lib/test.js")).to.be.true;
                        return [2 /*return*/];
                }
            });
        }); });
        it("rewrites require statements within to be relative", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var code;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, migrate_common_js_1.default(options)];
                    case 1:
                        _a.sent();
                        code = editor.read(dest + "/src/javascripts/lib/test.js");
                        chai_1.expect(code).to.match(/require\("\.\/utils\/test_utils\.js"\)/);
                        return [2 /*return*/];
                }
            });
        }); });
    });
});
