"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var memFs = require("mem-fs");
var fsEditor = require("mem-fs-editor");
var shelljs_1 = require("shelljs");
var migrate_images_1 = require("../../steps/migrate_images");
var immutable_1 = require("immutable");
describe("migrate images", function () {
    var editor;
    var options;
    var cwd = process.cwd();
    var src = cwd + "/tmp/test/v1_app";
    var dest = cwd + "/tmp/test/v2_app";
    beforeEach(function () {
        shelljs_1.mkdir("-p", [src, dest]);
        editor = fsEditor.create(memFs.create());
        options = immutable_1.Map({ src: src, dest: dest, editor: editor });
        editor.write(src + "/assets/logo.png", "");
    });
    afterEach(function () {
        shelljs_1.rm("-rf", [src, dest]);
    });
    it("should copy images to the destination", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var validExt;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    validExt = ['jpg', 'jpeg', 'gif', 'png', 'svg', 'woff', 'woff2'];
                    validExt.forEach(function (ext) {
                        editor.write(src + "/assets/test." + ext, "");
                    });
                    return [4 /*yield*/, migrate_images_1.default(options)];
                case 1:
                    _a.sent();
                    validExt.forEach(function (ext) {
                        chai_1.expect(editor.exists(dest + "/src/images/test." + ext)).to.be.true;
                    });
                    return [2 /*return*/];
            }
        });
    }); });
    it("ignores files that don't have a valid extension", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var invalidExt;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    invalidExt = ['swf', 'pdf', 'txt'];
                    invalidExt.forEach(function (ext) {
                        editor.write(src + "/assets/test." + ext, "");
                    });
                    return [4 /*yield*/, migrate_images_1.default(options)];
                case 1:
                    _a.sent();
                    invalidExt.forEach(function (ext) {
                        chai_1.expect(editor.exists(dest + "/src/images/test." + ext)).to.be.false;
                    });
                    return [2 /*return*/];
            }
        });
    }); });
});
