"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var memFs = require("mem-fs");
var fsEditor = require("mem-fs-editor");
var shelljs_1 = require("shelljs");
var migrate_templates_1 = require("../../steps/migrate_templates");
var immutable_1 = require("immutable");
describe("migrate templates", function () {
    var editor;
    var options;
    var cwd = process.cwd();
    var src = cwd + "/tmp/test/v1_app";
    var dest = cwd + "/tmp/test/v2_app";
    beforeEach(function () {
        shelljs_1.mkdir("-p", [src, dest]);
        editor = fsEditor.create(memFs.create());
        options = immutable_1.Map({ src: src, dest: dest, editor: editor });
        editor.write(src + "/templates/default.hdbs", "");
    });
    afterEach(function () {
        shelljs_1.rm("-rf", [src, dest]);
    });
    it("should copy templates to the destination", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    editor.write(src + "/templates/test.hdbs", "");
                    return [4 /*yield*/, migrate_templates_1.default(options)];
                case 1:
                    _a.sent();
                    chai_1.expect(editor.exists(dest + "/src/templates/test.hdbs")).to.be.true;
                    return [2 /*return*/];
            }
        });
    }); });
    it("ignores files that don't have the hdbs extension", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    editor.write(src + "/templates/foo.handlebars", "");
                    return [4 /*yield*/, migrate_templates_1.default(options)];
                case 1:
                    _a.sent();
                    chai_1.expect(editor.exists(dest + "/src/templates/foo.handlebars")).to.be.false;
                    return [2 /*return*/];
            }
        });
    }); });
});
