"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var chaiAsPromised = require("chai-as-promised");
chai.use(chaiAsPromised);
var expect = chai.expect;
var shelljs_1 = require("shelljs");
var requirements_only_1 = require("../../steps/requirements_only");
var immutable_1 = require("immutable");
describe("requirements only", function () {
    var options;
    var src = process.cwd() + "/tmp/test/v1_app";
    beforeEach(function () {
        shelljs_1.mkdir("-p", src);
        options = immutable_1.Map({ src: src });
    });
    afterEach(function () {
        if (shelljs_1.test(src)) {
            shelljs_1.rm("-rf", src);
        }
    });
    describe("with an app.js file present", function () {
        beforeEach(function () { return shelljs_1.exec("echo '' > " + src + "/app.js"); });
        it("should pass when there is no requirements.json", function () {
            return expect(requirements_only_1.default(options)).to.eventually.be.fulfilled;
        });
        it("should pass when there is a requirements.json", function () {
            shelljs_1.exec("echo '' > " + src + "/requirements.json");
            return expect(requirements_only_1.default(options)).to.eventually.be.fulfilled;
        });
    });
    describe("with no app.js file present", function () {
        it("should pass when there is no requirements.json", function () {
            return expect(requirements_only_1.default(options)).to.eventually.be.fulfilled;
        });
        it("should raise exception when there is a requirements.json", function () {
            shelljs_1.exec("echo '' > " + src + "/requirements.json");
            return expect(requirements_only_1.default(options)).to.eventually.be.rejectedWith(Error);
        });
    });
});
