"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var memFs = require("mem-fs");
var fsEditor = require("mem-fs-editor");
var shelljs_1 = require("shelljs");
var setup_app_scaffold_1 = require("../../steps/setup_app_scaffold");
var immutable_1 = require("immutable");
describe("setup app scaffold", function () {
    var editor;
    var options;
    var cwd = process.cwd();
    var dest = cwd + "/tmp/test/v2_app";
    beforeEach(function () {
        shelljs_1.mkdir("-p", dest);
        editor = fsEditor.create(memFs.create());
        options = immutable_1.Map({ dest: dest, editor: editor });
    });
    afterEach(function () {
        shelljs_1.rm("-rf", dest);
    });
    it("should copy the app scaffold to the destination", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, setup_app_scaffold_1.default(options)];
                case 1:
                    _a.sent();
                    chai_1.expect(editor.readJSON(dest + "/package.json").name).to.equal("app_scaffold");
                    return [2 /*return*/];
            }
        });
    }); });
    it("should include dotfiles when copying", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, setup_app_scaffold_1.default(options)];
                case 1:
                    _a.sent();
                    chai_1.expect(editor.exists(dest + "/.eslintrc")).to.be.true;
                    return [2 /*return*/];
            }
        });
    }); });
    it("should add custom eslint configuration", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var rules, eslintConfig;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    rules = [
                        "unused-vars",
                        "undef",
                        "console",
                        "unreachable",
                        "debugger"
                    ];
                    return [4 /*yield*/, setup_app_scaffold_1.default(options)];
                case 1:
                    _a.sent();
                    eslintConfig = editor.readJSON(dest + "/.eslintrc", { rules: {} });
                    rules.forEach(function (rule) {
                        chai_1.expect(eslintConfig.rules).to.have.property("no-" + rule, 0);
                    });
                    chai_1.expect(eslintConfig).to.have.property("root", true);
                    chai_1.expect(eslintConfig.globals).to.have.property("helpers", true);
                    chai_1.expect(eslintConfig.globals).to.have.property("Base64", true);
                    return [2 /*return*/];
            }
        });
    }); });
});
