"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai = require("chai");
var chaiAsPromised = require("chai-as-promised");
chai.use(chaiAsPromised);
var expect = chai.expect;
var sinon_1 = require("sinon");
var shelljs_1 = require("shelljs");
var inquirer = require("inquirer");
var node_emoji_1 = require("node-emoji");
var setup_paths_1 = require("../../steps/setup_paths");
var immutable_1 = require("immutable");
describe("setup paths", function () {
    var options;
    var logSpy, promptStub;
    var path = process.cwd() + "/tmp/test/v1_app";
    beforeEach(function () {
        shelljs_1.mkdir("-p", path);
        options = immutable_1.Map({ path: path });
        logSpy = sinon_1.spy(console, "log");
        promptStub = sinon_1.stub(inquirer, "prompt");
    });
    afterEach(function () {
        shelljs_1.rm("-rf", path);
        logSpy.restore();
        promptStub.restore();
    });
    describe("when using the --replace-v1 option", function () {
        beforeEach(function () {
            options = options.set("replaceV1", true);
        });
        describe("when current app is a migrated app", function () {
            beforeEach(function () {
                shelljs_1.exec("echo '{ \"name\": \"app_scaffold\" }' > " + path + "/package.json");
                shelljs_1.mkdir("-p", path + "/v1");
            });
            it("should stop and raise exception", function () {
                return expect(setup_paths_1.default(options)).to.eventually.be.rejectedWith(Error, "It looks like you're attempting to migrate an app that has already been migrated " + node_emoji_1.emojify(":pouting_cat:"));
            });
        });
        describe("when current app is not a migrated app", function () {
            it("when rejected, should stop and raise exception", function () {
                promptStub.returns({ replace: false });
                return expect(setup_paths_1.default(options)).to.eventually.be.rejectedWith(Error, "Migration cancelled " + node_emoji_1.emojify(":crying_cat_face:"));
            });
            it("when approved, should proceed and notify back up path", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            promptStub.returns({ replace: true });
                            return [4 /*yield*/, setup_paths_1.default(options)];
                        case 1:
                            options = _a.sent();
                            expect(logSpy.calledWithMatch(sinon_1.match("v1 App will be backed up to: " + path + "/v1/"))).to.be.true;
                            expect(options.get("dest")).to.match(/\/v2\/$/);
                            return [2 /*return*/];
                    }
                });
            }); });
        });
    });
    describe("when not using the --replace-v1 option", function () {
        it("should set destination to a v2 folder", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, setup_paths_1.default(options)];
                    case 1:
                        options = _a.sent();
                        expect(options.get("dest")).to.match(/\/v2\/$/);
                        return [2 /*return*/];
                }
            });
        }); });
    });
});
