"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var babylon_1 = require("babylon");
var babel_traverse_1 = require("babel-traverse");
var babel_generator_1 = require("babel-generator");
var types = require("babel-types");
var path_1 = require("path");
function tryResolve(path) {
    try {
        require.resolve(path);
        return true;
    }
    catch (error) {
        return false;
    }
}
function isRequireStatement(path) {
    return (path.isCallExpression() &&
        path.get("callee").isIdentifier() &&
        path.node.callee.name === "require");
}
exports.isRequireStatement = isRequireStatement;
function getDepthOfPath(path) {
    var depth = 0;
    path.findParent(function (p) {
        depth++;
        return p.isProgram();
    });
    return depth;
}
exports.getDepthOfPath = getDepthOfPath;
function findLowestDepthPath(ast, type) {
    var lowestDepth = Number.POSITIVE_INFINITY;
    var lowestDepthPath;
    babel_traverse_1.default(ast, (_a = {},
        _a[type] = function (path) {
            var depth = getDepthOfPath(path);
            if (!lowestDepthPath) {
                lowestDepthPath = path;
                lowestDepth = depth;
            }
            else if (lowestDepth > depth) {
                lowestDepthPath = path;
                lowestDepth = depth;
            }
        },
        _a));
    return lowestDepthPath;
    var _a;
}
exports.findLowestDepthPath = findLowestDepthPath;
function findModuleWithinDirs(modulePath, dirs, src) {
    var dir, newModulePath = modulePath;
    while (dirs.pop() !== "lib" && dirs.length > 0) {
        var remainingDirs = dirs.join(path_1.sep);
        var lookInDir = path_1.join(src, remainingDirs, newModulePath);
        newModulePath = path_1.join("..", newModulePath);
        if (tryResolve(lookInDir))
            return newModulePath;
    }
}
function relativeModulePath(modulePath, fileDir) {
    var paths = [];
    if (modulePath.indexOf("./") === -1)
        paths.push(".");
    if (fileDir === ".")
        paths.push("lib");
    paths.push(modulePath);
    return paths.join(path_1.sep);
}
function requireStatementProcessorFactory(options, pretty) {
    if (pretty === void 0) { pretty = true; }
    var src = options.get("src");
    return function (code, filePath) {
        var ast = babylon_1.parse(code.toString());
        var filePathWithoutSrc = filePath.replace(new RegExp("" + path_1.join(src, path_1.sep)), "");
        var fileDir = path_1.dirname(filePathWithoutSrc);
        var baseDir = fileDir === "." ? "lib" : fileDir;
        var dirs = baseDir.split(path_1.sep);
        babel_traverse_1.default(ast, {
            CallExpression: function (path) {
                var node = path.node;
                // Check whether there are any calls to `require("some_module")`
                if (isRequireStatement(path)) {
                    // Keep the path to the module
                    var modulePath = path.node.arguments[0]
                        .value;
                    // Check whether the module can be resolved by node
                    // based on the existing path value
                    var fp = path_1.join(src, baseDir, modulePath);
                    if (tryResolve(fp)) {
                        path
                            .get("arguments.0")
                            .replaceWith(types.stringLiteral(relativeModulePath(modulePath, fileDir)));
                    }
                    else {
                        var foundModulePath = findModuleWithinDirs(modulePath, dirs, src);
                        if (foundModulePath) {
                            path
                                .get("arguments.0")
                                .replaceWith(types.stringLiteral(foundModulePath));
                        }
                        else {
                            throw new Error("Unable to resolve Common JS module: " + modulePath);
                        }
                    }
                }
            }
        });
        return babel_generator_1.default(ast).code;
    };
}
exports.requireStatementProcessorFactory = requireStatementProcessorFactory;
